==> mitosheet2-0.1.45.tar.gz: package/lib/components/footer/DataSheetTabActions.js <==
// Copyright (c) Saga Inc.
import React, { useEffect } from 'react';
import { getRandomId } from '../../jupyter/api';
import Dropdown from '../elements/Dropdown';
import DropdownItem from '../elements/DropdownItem';
import DropdownSectionSeperator from '../elements/DropdownSectionSeperator';
import { ModalEnum } from '../modals/modals';
import { getDefaultGraphParams } from '../taskpanes/Graph/graphUtils';
import { TaskpaneType } from '../taskpanes/taskpanes';
/*
    Helper function for finding all of the graph tab names
    that are created from a given sheet index
*/
export const getGraphTabNamesAndIDsFromSheetIndex = (sheetIndex, graphDataDict) => {
    // Filter to only grapsh with the sheetIndex, and then get a list of the graph tab names
    const filteredGraphDataJSON = Object.fromEntries(Object.entries(graphDataDict || {}).filter(([, graphData]) => {
        return graphData.graphParams.graphCreation.sheet_index === sheetIndex;
    }));
    return Object.entries(filteredGraphDataJSON).map(([graphID, graphData]) => {
        return { graphTabName: graphData.graphTabName, graphID: graphID };
    });
};
/*
    Displays a set of actions one can perform on a data sheet tab, including
    deleting, duplicating, or renaming, and creating a sheet.
*/
export default function SheetTabActions(props) {
    // Log opening the data sheet tab actions
    useEffect(() => {
        if (props.display) {
            void props.mitoAPI.log('clicked_data_sheet_tab_actions', {
                sheet_index: props.sheetIndex
            });
        }
    }, [props.display]);
    const onDelete = async () => {
        const dependantGraphTabNamesAndIDs = getGraphTabNamesAndIDsFromSheetIndex(props.sheetIndex, props.graphDataDict);
        if (dependantGraphTabNamesAndIDs.length > 0) {
            props.setUIState(prevUIState => {
                return Object.assign(Object.assign({}, prevUIState), { currOpenModal: {
                        type: ModalEnum.DeleteGraphs,
                        dependantGraphTabNamesAndIDs: dependantGraphTabNamesAndIDs,
                        sheetIndex: props.sheetIndex
                    } });
            });
        }
        else {
            // Select the previous sheet
            props.setUIState(prevUIState => {
                return Object.assign(Object.assign({}, prevUIState), { selectedTabType: 'data', selectedSheetIndex: prevUIState.selectedSheetIndex > 0 ? prevUIState.selectedSheetIndex - 1 : 0 });
            });
            // Close 
            props.closeOpenEditingPopups();
            await props.mitoAPI.editDataframeDelete(props.sheetIndex);
        }
    };
    const onDuplicate = async () => {
        // Close 
        props.closeOpenEditingPopups();
        await props.mitoAPI.editDataframeDuplicate(props.sheetIndex);
    };
    /* Rename helper, which requires changes to the sheet tab itself */
    const onRename = () => {
        props.setIsRename(true);
    };
    const graphData = async () => {
        const newGraphID = getRandomId(); // Create a new graph
        const graphParams = getDefaultGraphParams(props.sheetDataArray, props.sheetIndex);
        await props.mitoAPI.editGraph(newGraphID, graphParams, '100%', '100%', undefined);
    };
    const openDownloadTaskpane = async () => {
        props.setUIState(prevUIState => {
            return Object.assign(Object.assign({}, prevUIState), { currOpenTaskpane: { type: TaskpaneType.DOWNLOAD }, currOpenModal: { type: ModalEnum.None } });
        });
    };
    return (React.createElement(Dropdown, { display: props.display, closeDropdown: () => props.setDisplayActions(false), width: 'small', supressFocusSettingOnClose: true },
        React.createElement(DropdownItem, { title: 'Create graph', onClick: (e) => {
                // Stop propogation so that the onClick of the sheet tab div
                // doesn't compete updating the uiState to this sheet instead of
                // the new graphID that we're creating
                e === null || e === void 0 ? void 0 : e.stopPropagation();
                void graphData();
            } }),
        React.createElement(DropdownItem, { title: 'Export', onClick: openDownloadTaskpane }),
        React.createElement(DropdownSectionSeperator, { isDropdownSectionSeperator: true }),
        React.createElement(DropdownItem, { title: 'Duplicate', onClick: onDuplicate }),
        React.createElement(DropdownItem, { title: 'Rename', onClick: onRename }),
        React.createElement(DropdownItem, { title: 'Delete', onClick: (e) => {
                // Stop propogation so that the onClick of the sheet tab div
                // doesn't compete updating the uiState to the graphID that is gettind deleted
                e === null || e === void 0 ? void 0 : e.stopPropagation();
                void onDelete();
            } })));
}
//# sourceMappingURL=DataSheetTabActions.js.map

==> mitosheet2-0.1.50.tar.gz: package/lib/components/footer/DataSheetTabActions.js <==
// Copyright (c) Saga Inc.
import React, { useEffect } from 'react';
import { getRandomId } from '../../jupyter/api';
import Dropdown from '../elements/Dropdown';
import DropdownItem from '../elements/DropdownItem';
import DropdownSectionSeperator from '../elements/DropdownSectionSeperator';
import { ModalEnum } from '../modals/modals';
import { getDefaultGraphParams } from '../taskpanes/Graph/graphUtils';
import { TaskpaneType } from '../taskpanes/taskpanes';
/*
    Helper function for finding all of the graph tab names
    that are created from a given sheet index
*/
export const getGraphTabNamesAndIDsFromSheetIndex = (sheetIndex, graphDataDict) => {
    // Filter to only grapsh with the sheetIndex, and then get a list of the graph tab names
    const filteredGraphDataJSON = Object.fromEntries(Object.entries(graphDataDict || {}).filter(([, graphData]) => {
        return graphData.graphParams.graphCreation.sheet_index === sheetIndex;
    }));
    return Object.entries(filteredGraphDataJSON).map(([graphID, graphData]) => {
        return { graphTabName: graphData.graphTabName, graphID: graphID };
    });
};
/*
    Displays a set of actions one can perform on a data sheet tab, including
    deleting, duplicating, or renaming, and creating a sheet.
*/
export default function SheetTabActions(props) {
    // Log opening the data sheet tab actions
    useEffect(() => {
        if (props.display) {
            void props.mitoAPI.log('clicked_data_sheet_tab_actions', {
                sheet_index: props.sheetIndex
            });
        }
    }, [props.display]);
    const onDelete = async () => {
        const dependantGraphTabNamesAndIDs = getGraphTabNamesAndIDsFromSheetIndex(props.sheetIndex, props.graphDataDict);
        if (dependantGraphTabNamesAndIDs.length > 0) {
            props.setUIState(prevUIState => {
                return Object.assign(Object.assign({}, prevUIState), { currOpenModal: {
                        type: ModalEnum.DeleteGraphs,
                        dependantGraphTabNamesAndIDs: dependantGraphTabNamesAndIDs,
                        sheetIndex: props.sheetIndex
                    } });
            });
        }
        else {
            // Select the previous sheet
            props.setUIState(prevUIState => {
                return Object.assign(Object.assign({}, prevUIState), { selectedTabType: 'data', selectedSheetIndex: prevUIState.selectedSheetIndex > 0 ? prevUIState.selectedSheetIndex - 1 : 0 });
            });
            // Close 
            props.closeOpenEditingPopups();
            await props.mitoAPI.editDataframeDelete(props.sheetIndex);
        }
    };
    const onDuplicate = async () => {
        // Close 
        props.closeOpenEditingPopups();
        await props.mitoAPI.editDataframeDuplicate(props.sheetIndex);
    };
    /* Rename helper, which requires changes to the sheet tab itself */
    const onRename = () => {
        props.setIsRename(true);
    };
    const graphData = async () => {
        const newGraphID = getRandomId(); // Create a new graph
        const graphParams = getDefaultGraphParams(props.sheetDataArray, props.sheetIndex);
        await props.mitoAPI.editGraph(newGraphID, graphParams, '100%', '100%', undefined);
    };
    const openDownloadTaskpane = async () => {
        props.setUIState(prevUIState => {
            return Object.assign(Object.assign({}, prevUIState), { currOpenTaskpane: { type: TaskpaneType.DOWNLOAD }, currOpenModal: { type: ModalEnum.None } });
        });
    };
    return (React.createElement(Dropdown, { display: props.display, closeDropdown: () => props.setDisplayActions(false), width: 'small' },
        React.createElement(DropdownItem, { title: 'Create graph', onClick: (e) => {
                // Stop propogation so that the onClick of the sheet tab div
                // doesn't compete updating the uiState to this sheet instead of
                // the new graphID that we're creating
                e === null || e === void 0 ? void 0 : e.stopPropagation();
                void graphData();
            } }),
        React.createElement(DropdownItem, { title: 'Export', onClick: openDownloadTaskpane }),
        React.createElement(DropdownSectionSeperator, { isDropdownSectionSeperator: true }),
        React.createElement(DropdownItem, { title: 'Duplicate', onClick: onDuplicate }),
        React.createElement(DropdownItem, { title: 'Rename', onClick: onRename, supressFocusSettingOnClose: true }),
        React.createElement(DropdownItem, { title: 'Delete', onClick: (e) => {
                // Stop propogation so that the onClick of the sheet tab div
                // doesn't compete updating the uiState to the graphID that is gettind deleted
                e === null || e === void 0 ? void 0 : e.stopPropagation();
                void onDelete();
            } })));
}
//# sourceMappingURL=DataSheetTabActions.js.map
